@@ -1,47 +1,34 @@
 package String::Random::Regexp::regxstring;
 
 # we rely on having T_AVREF_REFCOUNT_FIXED
-use 5.16.0;
+use 5.016;
 
 use strict;
 use warnings;
 
-use vars qw($VERSION @ISA);
+our $VERSION = '1.00';
 
+use Exporter;
+# export our only sub by default:
 our @ISA = qw(Exporter);
-# the EXPORT_OK and EXPORT_TAGS is code by [kcott] @ Perlmongs.org, thanks!
-# see https://perlmonks.org/?node_id=11115288
-our (@EXPORT);
-
-our $VERSION = '0.04';
-
-BEGIN {
-	$VERSION = '0.04';
-	if ($] > 5.006) {
-		require XSLoader;
-		XSLoader::load(__PACKAGE__, $VERSION);
-	} else {
-		require DynaLoader;
-		@ISA = qw(DynaLoader);
-		__PACKAGE__->bootstrap;
-	}
-        # export these by default:
-	@EXPORT = qw/generate_random_strings/;
-}
+our @EXPORT = ('generate_random_strings');
+# load XS functions
+use XSLoader;
+XSLoader::load(__PACKAGE__, $VERSION);
 
+# It generates $N random strings given a regular expression.
 # $regx is a string containing a regular expression
 #       or a Regexp object constructed, e.g., via qr/.../
-# $N    is the number of random strings to generate
+# $N    is optional, it is the number of random strings to generate, default is 1.
 # $debug is optional, it can be 0 or 1 denoting name-like behaviour.
 # The sub returns undef on failure (e.g. bad parameters)
 # On success, it returns an array of $N random strings 
 sub generate_random_strings {
 	my ($regx, $N, $debug) = @_;
 
-	$debug //= 0;
+	if( ! defined $regx ){ print STDERR "generate_random_strings() : error, at least an input regular expression (either as a string or as a Regexp object) is expected.\n"; return undef }
 
 	my $regx_str;
-
 	if( ref($regx) eq '' ){ $regx_str = $regx }
 	elsif( ref($regx) eq 'Regexp' ){
 		# stringifying a regexp object results in the string regexp
@@ -53,6 +40,10 @@ sub generate_random_strings {
 		$regx_str =~ s/\)$//;
 	} else { print STDERR "generate_random_strings() : error, input regular expression must either be a string or a Regexp object (created via qr/.../) and not '".ref($regx)."'.\n"; return undef }
 
+	# default values if optional params are not specified:
+	$N //= 1;
+	$debug //= 0;
+
 	my $ret = generate_random_strings_xs(
 		$regx_str,
 		$N,
@@ -71,7 +62,7 @@ String::Random::Regexp::regxstring - Generate random strings from a regular expr
 
 =head1 VERSION
 
-Version 0.04
+Version 1.00
 
 =head1 SYNOPSIS
 
@@ -108,9 +99,7 @@ via XS.
 
 =over 4
 
-=item * C<generate_random_strings> : generates random strings
-
-=item * C<:all> : tag for exporting all available export symbols
+=item * C<generate_random_strings> : generates random strings. This sub is exported by default.
 
 =back
 
@@ -119,7 +108,7 @@ via XS.
 
 =head2 C<generate_random_strings>
 
-    my $strings = generate_random_strings($regexp, $N, [$debug])
+    my $strings = generate_random_strings($regexp [, $N, $debug])
 
 
 Arguments:
@@ -129,7 +118,7 @@ Arguments:
 =item * C<$regexp> : a regular expression either as a string
 or as a Regexp object created via e.g. C<qr/.../>
 
-=item * C<$N> : the number of random strings to generate.
+=item * C<$N> : optionally specify the number of random strings to generate. Default is 1.
 
 =item * C<$debug> : optionally enable debug, if set to 1. By default it is turned off.
 
